pm4py.statistics.passed\_time.pandas.variants package
=====================================================

Submodules
----------

pm4py.statistics.passed\_time.pandas.variants.post module
---------------------------------------------------------

.. automodule:: pm4py.statistics.passed_time.pandas.variants.post
   :members:
   :undoc-members:
   :show-inheritance:

pm4py.statistics.passed\_time.pandas.variants.pre module
--------------------------------------------------------

.. automodule:: pm4py.statistics.passed_time.pandas.variants.pre
   :members:
   :undoc-members:
   :show-inheritance:

pm4py.statistics.passed\_time.pandas.variants.prepost module
------------------------------------------------------------

.. automodule:: pm4py.statistics.passed_time.pandas.variants.prepost
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pm4py.statistics.passed_time.pandas.variants
   :members:
   :undoc-members:
   :show-inheritance:
